package App::TermAttrUtils;

our $DATE = '2019-10-03'; # DATE
our $VERSION = '0.004'; # VERSION

1;
# ABSTRACT: CLI utilities related to querying terminal attributes

__END__

=pod

=encoding UTF-8

=head1 NAME

App::TermAttrUtils - CLI utilities related to querying terminal attributes

=head1 VERSION

This document describes version 0.004 of App::TermAttrUtils (from Perl distribution App-TermAttrUtils), released on 2019-10-03.

=head1 DESCRIPTION

This distributions provides the following command-line utilities related to
querying terminal attributes (color support, size, other capabilities):

=over

=item * L<term-attrs>

=item * L<term-detect-software>

=item * L<term-terminfo>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-TermAttrUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-TermAttrUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-TermAttrUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<App::XTermUtils>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
